@@ -30,6 +30,16 @@ module Vagrant
         def call(env)
           @download_interrupted = false
 
+          unless env[:box_name].nil?
+            begin
+              if URI.parse(env[:box_name]).kind_of?(URI::HTTP)
+                env[:ui].warn(I18n.t("vagrant.box_add_url_warn"))
+              end
+            rescue URI::InvalidURIError
+              # do nothing
+            end
+          end
+
           url = Array(env[:box_url]).map do |u|
             u = u.gsub("\\", "/")
             if Util::Platform.windows? && u =~ /^[a-z]:/i
@@ -168,12 +178,15 @@ module Vagrant
             url               = url[0]
           end
 
+          display_original_url = Util::CredentialScrubber.scrub(Array(original_url).first)
+          display_url = Util::CredentialScrubber.scrub(url)
+
           env[:ui].output(I18n.t(
             "vagrant.box_loading_metadata",
-            name: Array(original_url).first))
+            name: display_original_url))
           if original_url != url
             env[:ui].detail(I18n.t(
-              "vagrant.box_expanding_url", url: url))
+              "vagrant.box_expanding_url", url: display_url))
           end
 
           metadata = nil
@@ -189,8 +202,8 @@ module Vagrant
             raise if !expanded
             raise Errors::BoxAddShortNotFound,
               error: e.extra_data[:message],
-              name: original_url,
-              url: url
+              name: display_original_url,
+              url: display_url
           ensure
             metadata_path.delete if metadata_path && metadata_path.file?
           end
@@ -208,12 +221,12 @@ module Vagrant
               raise Errors::BoxAddNoMatchingProvider,
                 name: metadata.name,
                 requested: provider,
-                url: url
+                url: display_url
             else
               raise Errors::BoxAddNoMatchingVersion,
                 constraints: version || ">= 0",
                 name: metadata.name,
-                url: url,
+                url: display_url,
                 versions: metadata.versions.join(", ")
             end
           end
@@ -265,7 +278,7 @@ module Vagrant
               raise "Bad box authentication hook, did not generate proper results."
             end
             provider_url = authed_urls[0]
-        end
+          end
 
           box_add(
             [[provider_url, metadata_provider.url]],
@@ -429,6 +442,7 @@ module Vagrant
           if opts[:ui]
             show_url = opts[:show_url]
             show_url ||= url
+            display_url = Util::CredentialScrubber.scrub(show_url)
 
             translation = "vagrant.box_downloading"
 
@@ -439,7 +453,7 @@ module Vagrant
 
             env[:ui].detail(I18n.t(
               translation,
-              url: show_url))
+              url: display_url))
             if File.file?(d.destination)
               env[:ui].info(I18n.t("vagrant.actions.box.download.resuming"))
             end
@@ -474,6 +488,7 @@ module Vagrant
             url ||= uri.opaque
             #7570 Strip leading slash left in front of drive letter by uri.path
             Util::Platform.windows? && url.gsub!(/^\/([a-zA-Z]:)/, '\1')
+            url = URI.unescape(url)
 
             begin
               File.open(url, "r") do |f|
