@@ -49,7 +49,7 @@ module Vagrant
         # Run the action chain in a busy block, marking the environment as
         # interrupted if a SIGINT occurs, and exiting cleanly once the
         # chain has been run.
-        ui = environment[:ui] if environment.has_key?(:ui)
+        ui = environment[:ui] if environment.key?(:ui)
         int_callback = lambda do
           if environment[:interrupted]
             ui.error I18n.t("vagrant.actions.runner.exit_immediately") if ui
@@ -62,7 +62,7 @@ module Vagrant
         end
 
         # We place a process lock around every action that is called
-        @logger.info("Running action: #{callable_id}")
+        @logger.info("Running action: #{environment[:action_name]} #{callable_id}")
         Util::Busy.busy(int_callback) { callable.call(environment) }
 
         # Return the environment in case there are things in there that
