@@ -6,8 +6,11 @@ require_relative "../client"
 module VagrantPlugins
   module LoginCommand
     class AddAuthentication
-      VCLOUD = "vagrantcloud.com".freeze
-      ATLAS  = "atlas.hashicorp.com".freeze
+      ALLOWED_AUTHENTICATION_HOSTS = %w[
+        app.vagrantup.com
+        atlas.hashicorp.com
+        vagrantcloud.com
+      ].freeze
 
       def initialize(app, env)
         @app = app
@@ -25,11 +28,8 @@ module VagrantPlugins
             replace = u.host == server_uri.host
 
             if !replace
-              # We need this in here for the transition we made from
-              # Vagrant Cloud to Atlas. This preserves access tokens
-              # appending to both without leaking access tokens to
-              # unsavory URLs.
-              if u.host == VCLOUD && server_uri.host == ATLAS
+              if ALLOWED_AUTHENTICATION_HOSTS.include?(u.host) &&
+                  ALLOWED_AUTHENTICATION_HOSTS.include?(server_uri.host)
                 replace = true
               end
             end
