@@ -12,8 +12,10 @@ module VagrantPlugins
         def call(env)
           # Remove it!
           env[:ui].info(I18n.t("vagrant.commands.plugin.uninstalling",
-                               :name => env[:plugin_name]))
-          env[:plugin_state_file].remove_plugin(env[:plugin_name])
+                               name: env[:plugin_name]))
+
+          manager = Vagrant::Plugin::Manager.instance
+          manager.uninstall_plugin(env[:plugin_name])
 
           @app.call(env)
         end
