@@ -22,8 +22,7 @@ module VagrantPlugins
             end
 
             if !vm.provider.capability?(:snapshot_list)
-              vm.ui.info(I18n.t("vagrant.commands.snapshot.not_supported"))
-              next
+              raise Vagrant::Errors::SnapshotNotSupported
             end
 
             snapshots = vm.provider.capability(:snapshot_list)
