@@ -4,6 +4,7 @@ module VagrantPlugins
       class ShellExpandGuestPath
         def self.shell_expand_guest_path(machine, path)
           real_path = nil
+          path = path.gsub(/ /, '\ ')
           machine.communicate.execute("printf #{path}") do |type, data|
             if type == :stdout
               real_path ||= ""
@@ -14,7 +15,7 @@ module VagrantPlugins
           if !real_path
             # If no real guest path was detected, this is really strange
             # and we raise an exception because this is a bug.
-            raise ShellExpandFailed
+            raise Vagrant::Errors::ShellExpandFailed
           end
 
           # Chomp the string so that any trailing newlines are killed
