@@ -23,20 +23,13 @@ module VagrantPlugins
                 hostname -F /etc/hostname
               fi
 
-              # Remove comments and blank lines from /etc/hosts
-              sed -i'' -e 's/#.*$//' -e '/^$/d' /etc/hosts
-
               # Prepend ourselves to /etc/hosts
               grep -w '#{name}' /etc/hosts || {
                 sed -i'' '1i 127.0.0.1\\t#{name}\\t#{basename}' /etc/hosts
               }
 
-              # Restart network (through NetworkManager if running)
-              if service NetworkManager status 2>&1 | grep -q running; then
-                service NetworkManager restart
-              else
-                service network restart
-              fi
+              # Restart network
+              service network restart
             EOH
           end
         end
