@@ -5,7 +5,7 @@ module VagrantPlugins
         def self.halt(machine)
           begin
             machine.communicate.sudo("/sbin/shutdown -h now")
-          rescue IOError
+          rescue IOError, Vagrant::Errors::SSHDisconnected
             # Do nothing, because it probably means the machine shut down
             # and SSH connection was lost.
           end
