@@ -4,7 +4,7 @@ module VagrantPlugins
   module HostSlackware
     class Host < Vagrant.plugin("2", :host)
       def detect?(env)
-        return File.exists?("/etc/slackware-release") ||
+        return File.exists?("/etc/slackware-version") ||
           !Dir.glob("/usr/lib/setup/Plamo-*").empty?
       end
     end
