@@ -9,6 +9,10 @@ module VagrantPlugins
       attr_accessor :insert_key
       attr_accessor :keys_only
       attr_accessor :paranoid
+      attr_accessor :verify_host_key
+      attr_accessor :compression
+      attr_accessor :dsa_authentication
+      attr_accessor :extra_args
 
       def initialize
         @host             = UNSET_VALUE
@@ -19,6 +23,10 @@ module VagrantPlugins
         @insert_key       = UNSET_VALUE
         @keys_only        = UNSET_VALUE
         @paranoid         = UNSET_VALUE
+        @verify_host_key  = UNSET_VALUE
+        @compression      = UNSET_VALUE
+        @dsa_authentication = UNSET_VALUE
+        @extra_args       = UNSET_VALUE
       end
 
       def finalize!
@@ -30,10 +38,19 @@ module VagrantPlugins
         @insert_key       = true if @insert_key == UNSET_VALUE
         @keys_only        = true if @keys_only == UNSET_VALUE
         @paranoid         = false if @paranoid == UNSET_VALUE
+        @verify_host_key  = false if @verify_host_key == UNSET_VALUE
+        @compression      = true if @compression == UNSET_VALUE
+        @dsa_authentication = true if @dsa_authentication == UNSET_VALUE
+        @extra_args       = nil if @extra_args == UNSET_VALUE
 
         if @private_key_path && !@private_key_path.is_a?(Array)
           @private_key_path = [@private_key_path]
         end
+
+        if @paranoid
+          @verify_host_key = @paranoid
+        end
+
       end
 
       # NOTE: This is _not_ a valid config validation method, since it
@@ -55,6 +72,10 @@ module VagrantPlugins
           end
         end
 
+        if @paranoid
+          machine.env.ui.warn(I18n.t("vagrant.config.ssh.paranoid_deprecated"))
+        end
+
         errors
       end
     end
