@@ -145,18 +145,16 @@ module VagrantPlugins
           new_provs   = []
           other_provs = other.provisioners.dup
           @provisioners.each do |p|
-            if p.name
-              other_p = other_provs.find { |o| p.name == o.name }
-              if other_p
-                # There is an override. Take it.
-                other_p.config = p.config.merge(other_p.config)
-                other_p.run    ||= p.run
-                next if !other_p.preserve_order
+            other_p = other_provs.find { |o| p.id == o.id }
+            if other_p
+              # There is an override. Take it.
+              other_p.config = p.config.merge(other_p.config)
+              other_p.run    ||= p.run
+              next if !other_p.preserve_order
 
-                # We're preserving order, delete from other
-                p = other_p
-                other_provs.delete(other_p)
-              end
+              # We're preserving order, delete from other
+              p = other_p
+              other_provs.delete(other_p)
             end
 
             # There is an override, merge it into the
@@ -259,9 +257,11 @@ module VagrantPlugins
           default_id = nil
 
           if type == :forwarded_port
-            # For forwarded ports, set the default ID to the
-            # host port so that host ports overwrite each other.
-            default_id = "#{options[:protocol]}#{options[:host]}"
+            # For forwarded ports, set the default ID to be the
+            # concat of host_ip, proto and host_port. This would ensure Vagrant
+            # caters for port forwarding in an IP aliased environment where
+            # different host IP addresses are to be listened on the same port.
+            default_id = "#{options[:host_ip]}#{options[:protocol]}#{options[:host]}"
           end
 
           options[:id] = default_id || SecureRandom.uuid
@@ -697,7 +697,7 @@ module VagrantPlugins
             end
 
             if options[:host]
-              key = "#{options[:protocol]}#{options[:host]}"
+              key = "#{options[:host_ip]}#{options[:protocol]}#{options[:host]}"
               if fp_used.include?(key)
                 errors << I18n.t("vagrant.config.vm.network_fp_host_not_unique",
                                 host: options[:host].to_s,
