@@ -43,7 +43,7 @@ module VagrantPlugins
               dockerfile      = machine.provider_config.dockerfile
               dockerfile_path = File.join(build_dir, dockerfile)
 
-              args.push("--file=\"#{dockerfile_path}\"")
+              args.push("--file").push(dockerfile_path)
               machine.ui.output(
                 I18n.t("docker_provider.building_named_dockerfile",
                 file: machine.provider_config.dockerfile))
