@@ -19,6 +19,18 @@ module VagrantPlugins
       # @return [String]
       attr_accessor :build_dir
 
+      # Use docker-compose to manage the lifecycle and environment for
+      # containers instead of using docker directly.
+      #
+      # @return [Boolean]
+      attr_accessor :compose
+
+      # Configuration Hash used for build the docker-compose composition
+      # file. This can be used for adding networks or volumes.
+      #
+      # @return [Hash]
+      attr_accessor :compose_configuration
+
       # An optional file name of a Dockerfile to be used when building
       # the image. This requires Docker >1.5.0.
       #
@@ -138,6 +150,8 @@ module VagrantPlugins
         @build_args = []
         @build_dir  = UNSET_VALUE
         @cmd        = UNSET_VALUE
+        @compose    = UNSET_VALUE
+        @compose_configuration = {}
         @create_args = UNSET_VALUE
         @dockerfile = UNSET_VALUE
         @env        = {}
@@ -201,6 +215,7 @@ module VagrantPlugins
         @build_args = [] if @build_args == UNSET_VALUE
         @build_dir  = nil if @build_dir == UNSET_VALUE
         @cmd        = [] if @cmd == UNSET_VALUE
+        @compose    = false if @compose == UNSET_VALUE
         @create_args = [] if @create_args == UNSET_VALUE
         @dockerfile = nil if @dockerfile == UNSET_VALUE
         @env       ||= {}
@@ -228,13 +243,20 @@ module VagrantPlugins
         # host VM. Other users can optionally disable this by setting the
         # value explicitly to false in their Vagrantfile.
         if @force_host_vm == UNSET_VALUE
-          @force_host_vm = !Vagrant::Util::Platform.linux?
+          @force_host_vm = !Vagrant::Util::Platform.linux? &&
+            !Vagrant::Util::Platform.darwin? &&
+            !Vagrant::Util::Platform.windows?
         end
 
         # The machine name must be a symbol
         @vagrant_machine = @vagrant_machine.to_sym if @vagrant_machine
 
         @expose.uniq!
+
+        if @compose_configuration.is_a?(Hash)
+          # Ensures configuration is using basic types
+          @compose_configuration = JSON.parse(@compose_configuration.to_json)
+        end
       end
 
       def validate(machine)
@@ -255,6 +277,14 @@ module VagrantPlugins
           end
         end
 
+        if !@compose_configuration.is_a?(Hash)
+          errors << I18n.t("docker_provider.errors.config.compose_configuration_hash")
+        end
+
+        if @compose && @force_host_vm
+          errors << I18n.t("docker_provider.errors.config.compose_force_vm")
+        end
+
         if !@create_args.is_a?(Array)
           errors << I18n.t("docker_provider.errors.config.create_args_array")
         end
