@@ -9,6 +9,22 @@ module VagrantPlugins
         error_key(:communicator_non_docker)
       end
 
+      class ComposeLockTimeoutError < DockerError
+        error_key(:compose_lock_timeout)
+      end
+
+      class ContainerNotRunningError < DockerError
+        error_key(:not_running)
+      end
+
+      class ContainerNotCreatedError < DockerError
+        error_key(:not_created)
+      end
+
+      class DockerComposeNotInstalledError < DockerError
+        error_key(:docker_compose_not_installed)
+      end
+
       class ExecuteError < DockerError
         error_key(:execute_error)
       end
