@@ -41,6 +41,7 @@ module VagrantPlugins
               b2.use ProvisionerCleanup, :before
               b2.use StopInstance
               b2.use DeleteVM
+              b2.use SyncedFolderCleanup
             end
           end
         end
@@ -64,6 +65,28 @@ module VagrantPlugins
         end
       end
 
+      # This action packages the virtual machine into a single box file.
+      def self.action_package
+        Vagrant::Action::Builder.new.tap do |b|
+          b.use CheckEnabled
+          b.use Call, IsState, :not_created do |env1, b2|
+            if env1[:result]
+              b2.use Message, I18n.t("vagrant_hyperv.message_not_created")
+              next
+            end
+
+            b2.use PackageSetupFolders
+            b2.use PackageSetupFiles
+            b2.use action_halt
+            b2.use SyncedFolderCleanup
+            b2.use Package
+            b2.use PackageVagrantfile
+            b2.use PackageMetadataJson
+            b2.use Export
+          end
+        end
+      end
+
       def self.action_provision
         Vagrant::Action::Builder.new.tap do |b|
           b.use ConfigValidate
@@ -122,6 +145,7 @@ module VagrantPlugins
               b2.use StartInstance
               b2.use WaitForIPAddress
               b2.use WaitForCommunicator, [:running]
+              b2.use SyncedFolderCleanup
               b2.use SyncedFolders
               b2.use SetHostname
             end
@@ -156,14 +180,12 @@ module VagrantPlugins
           b.use ConfigValidate
           b.use Call, IsState, :not_created do |env, b2|
             if env[:result]
-              b2.use Message, I18n.t("vagrant_hyperv.message_not_created")
-              next
+              raise Vagrant::Errors::VMNotCreatedError
             end
 
             b2.use Call, IsState, :running do |env1, b3|
               if !env1[:result]
-                b3.use Message, I18n.t("vagrant_hyperv.message_not_running")
-                next
+                raise Vagrant::Errors::VMNotRunningError
               end
 
               b3.use SSHExec
@@ -177,14 +199,12 @@ module VagrantPlugins
           b.use ConfigValidate
           b.use Call, IsState, :not_created do |env, b2|
             if env[:result]
-              b2.use Message, I18n.t("vagrant_hyperv.message_not_created")
-              next
+              raise Vagrant::Errors::VMNotCreatedError
             end
 
             b2.use Call, IsState, :running do |env1, b3|
               if !env1[:result]
-                b3.use Message, I18n.t("vagrant_hyperv.message_not_running")
-                next
+                raise Vagrant::Errors::VMNotRunningError
               end
 
               b3.use SSHRun
@@ -261,9 +281,16 @@ module VagrantPlugins
 
       # The autoload farm
       action_root = Pathname.new(File.expand_path("../action", __FILE__))
+      autoload :PackageSetupFolders, action_root.join("package_setup_folders")
+      autoload :PackageSetupFiles, action_root.join("package_setup_files")
+      autoload :PackageVagrantfile, action_root.join("package_vagrantfile")
+      autoload :PackageMetadataJson, action_root.join("package_metadata_json")
+      autoload :Export, action_root.join("export")
+
       autoload :CheckEnabled, action_root.join("check_enabled")
       autoload :DeleteVM, action_root.join("delete_vm")
       autoload :Import, action_root.join("import")
+      autoload :Package, action_root.join("package")
       autoload :IsWindows, action_root.join("is_windows")
       autoload :ReadState, action_root.join("read_state")
       autoload :ResumeVM, action_root.join("resume_vm")
