@@ -8,13 +8,17 @@ module VagrantPlugins
         module Fedora
           module AnsibleInstall
 
-            def self.ansible_install(machine, install_mode, ansible_version)
-              rpm_package_manager = Facts::rpm_package_manager(machine)
-
-              if install_mode == :pip
+            def self.ansible_install(machine, install_mode, ansible_version, pip_args)
+              case install_mode
+              when :pip
                 pip_setup machine
-                Pip::pip_install machine, "ansible", ansible_version
+                Pip::pip_install machine, "ansible", ansible_version, pip_args, true
+              when :pip_args_only
+                pip_setup machine
+                Pip::pip_install machine, "", "", pip_args, false
               else
+                rpm_package_manager = Facts::rpm_package_manager(machine)
+
                 machine.communicate.sudo "#{rpm_package_manager} -y install ansible"
               end
             end
