@@ -5,15 +5,17 @@ module VagrantPlugins
       module Guest
         module Pip
 
-          def self.pip_install(machine, package, version = "", upgrade = true)
-            upgrade_arg = "--upgrade " if upgrade
+          def self.pip_install(machine, package = "", version = "", pip_args = "", upgrade = true)
+            upgrade_arg = "--upgrade" if upgrade
             version_arg = ""
 
             if !version.to_s.empty? && version.to_s.to_sym != :latest
               version_arg = "==#{version}"
             end
 
-            machine.communicate.sudo "pip install #{upgrade_arg}#{package}#{version_arg}"
+            args_array = [pip_args, upgrade_arg, "#{package}#{version_arg}"]
+
+            machine.communicate.sudo "pip install #{args_array.join(' ')}"
           end
 
           def self.get_pip(machine)
