@@ -10,16 +10,16 @@ module VagrantPlugins
         attr_accessor :tmp_path
         attr_accessor :install
         attr_accessor :install_mode
-        attr_accessor :version
+        attr_accessor :pip_args
 
         def initialize
           super
 
           @install           = UNSET_VALUE
           @install_mode      = UNSET_VALUE
+          @pip_args          = UNSET_VALUE
           @provisioning_path = UNSET_VALUE
           @tmp_path          = UNSET_VALUE
-          @version           = UNSET_VALUE
         end
 
         def finalize!
@@ -27,16 +27,19 @@ module VagrantPlugins
 
           @install           = true                   if @install           == UNSET_VALUE
           @install_mode      = :default               if @install_mode      == UNSET_VALUE
+          @pip_args          = ""                     if @pip_args          == UNSET_VALUE
           @provisioning_path = "/vagrant"             if provisioning_path  == UNSET_VALUE
           @tmp_path          = "/tmp/vagrant-ansible" if tmp_path           == UNSET_VALUE
-          @version           = ""                     if @version           == UNSET_VALUE
         end
 
         def validate(machine)
           super
 
-          if @install_mode.to_s.to_sym == :pip
+          case @install_mode.to_s.to_sym
+          when :pip
             @install_mode = :pip
+          when :pip_args_only
+            @install_mode = :pip_args_only
           else
             @install_mode = :default
           end
