@@ -10,12 +10,14 @@ module VagrantPlugins
 
         def initialize(machine, config)
           super
+          @control_machine = "guest"
           @logger = Log4r::Logger.new("vagrant::provisioners::ansible_guest")
         end
 
         def provision
           check_files_existence
           check_and_install_ansible
+
           execute_ansible_galaxy_on_guest if config.galaxy_role_file
           execute_ansible_playbook_on_guest
         end
@@ -25,14 +27,14 @@ module VagrantPlugins
         #
         # This handles verifying the Ansible installation, installing it if it was
         # requested, and so on. This method will raise exceptions if things are wrong.
+        # The compatibility mode checks are also performed here in order to fetch the
+        # Ansible version information only once.
         #
         # Current limitations:
-        #   - The installation of a specific Ansible version is not supported.
-        #     Such feature is difficult to systematically provide via package repositories (apt, yum, ...).
-        #     Installing via pip python packaging or directly from github source would be appropriate,
-        #     but these approaches require more dependency burden.
-        #   - There is no guarantee that the automated installation will replace
-        #     a previous Ansible installation.
+        #   - The installation of a specific Ansible version is only supported by
+        #     the "pip" install_mode.
+        #   - There is no absolute guarantee that the automated installation will replace
+        #     a previous Ansible installation (although it works fine in many cases)
         #
         def check_and_install_ansible
           @logger.info("Checking for Ansible installation...")
@@ -49,24 +51,42 @@ module VagrantPlugins
              (config.version.to_s.to_sym == :latest ||
               !@machine.guest.capability(:ansible_installed, config.version))
             @machine.ui.detail I18n.t("vagrant.provisioners.ansible.installing")
-            @machine.guest.capability(:ansible_install, config.install_mode, config.version)
+            @machine.guest.capability(:ansible_install, config.install_mode, config.version, config.pip_args)
           end
 
-          # Check that Ansible Playbook command is available on the guest
-          @machine.communicate.execute(
-            "test -x \"$(command -v #{config.playbook_command})\"",
-            error_class: Ansible::Errors::AnsibleNotFoundOnGuest,
-            error_key: :ansible_not_found_on_guest
-          )
+          # This step will also fetch the Ansible version data into related instance variables
+          set_and_check_compatibility_mode
 
           # Check if requested ansible version is available
           if (!config.version.empty? &&
               config.version.to_s.to_sym != :latest &&
-              !@machine.guest.capability(:ansible_installed, config.version))
-            raise Ansible::Errors::AnsibleVersionNotFoundOnGuest, required_version: config.version.to_s
+              config.version != @gathered_version)
+            raise Ansible::Errors::AnsibleVersionMismatch,
+              system: @control_machine,
+              required_version: config.version,
+              current_version: @gathered_version
           end
         end
 
+        def gather_ansible_version
+          raw_output = ""
+
+          result = @machine.communicate.execute(
+            "ansible --version",
+            error_class: Ansible::Errors::AnsibleNotFoundOnGuest,
+            error_key: :ansible_not_found_on_guest) do |type, output|
+            if type == :stdout && output.lines[0]
+              raw_output = output.lines[0]
+            end
+          end
+
+          if result != 0
+            raw_output = ""
+          end
+
+          raw_output
+        end
+
         def get_provisioning_working_directory
           config.provisioning_path
         end
@@ -159,7 +179,7 @@ module VagrantPlugins
             error_key: :config_file_not_found,
             config_option: option_name,
             path: remote_path,
-            system: "guest"
+            system: @control_machine
           )
         end
 
