@@ -13,6 +13,7 @@ module VagrantPlugins
         attr_accessor :manifests_path
         attr_accessor :environment
         attr_accessor :environment_path
+        attr_accessor :environment_variables
         attr_accessor :module_path
         attr_accessor :options
         attr_accessor :synced_folder_type
@@ -23,18 +24,19 @@ module VagrantPlugins
         def initialize
           super
 
-          @binary_path        = UNSET_VALUE
-          @hiera_config_path  = UNSET_VALUE
-          @manifest_file      = UNSET_VALUE
-          @manifests_path     = UNSET_VALUE
-          @environment        = UNSET_VALUE
-          @environment_path   = UNSET_VALUE
-          @module_path        = UNSET_VALUE
-          @options            = []
-          @facter             = {}
-          @synced_folder_type = UNSET_VALUE
-          @temp_dir           = UNSET_VALUE
-          @working_directory  = UNSET_VALUE
+          @binary_path           = UNSET_VALUE
+          @hiera_config_path     = UNSET_VALUE
+          @manifest_file         = UNSET_VALUE
+          @manifests_path        = UNSET_VALUE
+          @environment           = UNSET_VALUE
+          @environment_path      = UNSET_VALUE
+          @environment_variables = UNSET_VALUE
+          @module_path           = UNSET_VALUE
+          @options               = []
+          @facter                = {}
+          @synced_folder_type    = UNSET_VALUE
+          @temp_dir              = UNSET_VALUE
+          @working_directory     = UNSET_VALUE
         end
 
         def nfs=(value)
@@ -87,6 +89,10 @@ module VagrantPlugins
             end
           end
 
+          if @environment_variables == UNSET_VALUE
+            @environment_variables = {}
+          end
+
           @binary_path        = nil     if @binary_path == UNSET_VALUE
           @module_path        = nil     if @module_path == UNSET_VALUE
           @synced_folder_type = nil     if @synced_folder_type == UNSET_VALUE
