@@ -121,7 +121,7 @@ module VagrantPlugins
           options = "%s -F -c %s" % [options, config_dir]
         end
 
-        if @config.seed_master && @config.install_master
+        if @config.seed_master && @config.install_master && @machine.config.vm.communicator != :winrm
           seed_dir = "/tmp/minion-seed-keys"
           @machine.communicate.sudo("mkdir -p -m777 #{seed_dir}")
           @config.seed_master.each do |name, keyfile|
@@ -132,27 +132,27 @@ module VagrantPlugins
           options = "#{options} -k #{seed_dir}"
         end
 
-        if configure && !install
+        if configure && !install && @machine.config.vm.communicator != :winrm
           options = "%s -C" % options
         end
 
-        if @config.install_master
+        if @config.install_master && @machine.config.vm.communicator != :winrm
           options = "%s -M" % options
         end
 
-        if @config.install_syndic
+        if @config.install_syndic && @machine.config.vm.communicator != :winrm
           options = "%s -S" % options
         end
 
-        if @config.no_minion
+        if @config.no_minion && @machine.config.vm.communicator != :winrm
           options = "%s -N" % options
         end
 
-        if @config.install_type
+        if @config.install_type && @machine.config.vm.communicator != :winrm
           options = "%s %s" % [options, @config.install_type]
         end
 
-        if @config.install_args
+        if @config.install_args && @machine.config.vm.communicator != :winrm
           options = "%s %s" % [options, @config.install_args]
         end
 
@@ -184,6 +184,30 @@ module VagrantPlugins
         end
       end
 
+      # Get command-line options for masterless provisioning
+      def get_masterless
+        options = ""
+
+        if @config.masterless
+          options = " --local"
+          if @config.minion_id
+            options += " --id #{@config.minion_id}"
+          end
+        end
+
+        return options
+      end
+
+      # Append additional arguments to the salt command
+      def get_salt_args
+        " " + Array(@config.salt_args).join(" ")
+      end
+
+      # Append additional arguments to the salt-call command
+      def get_call_args
+        " " + Array(@config.salt_call_args).join(" ")
+      end
+
       # Copy master and minion configs to VM
       def upload_configs
         if @config.minion_config
@@ -253,6 +277,9 @@ module VagrantPlugins
             if @config.version
               options += " -version %s" % @config.version
             end
+            if @config.python_version
+              options += " -pythonVersion %s" % @config.python_version
+            end
             if @config.run_service
               @machine.env.ui.info "Salt minion will be stopped after installing."
               options += " -runservice %s" % @config.run_service
@@ -276,7 +303,7 @@ module VagrantPlugins
           @machine.communicate.upload(bootstrap_path.to_s, bootstrap_destination)
           @machine.communicate.sudo("chmod +x %s" % bootstrap_destination)
           if @machine.config.vm.communicator == :winrm
-            bootstrap = @machine.communicate.sudo("powershell.exe -executionpolicy bypass -file %s %s" % [bootstrap_destination, options]) do |type, data|
+            bootstrap = @machine.communicate.sudo("powershell.exe -NonInteractive -NoProfile -executionpolicy bypass -file %s %s" % [bootstrap_destination, options]) do |type, data|
               if data[0] == "\n"
                 # Remove any leading newline but not whitespace. If we wanted to
                 # remove newlines and whitespace we would have used data.lstrip
@@ -317,10 +344,15 @@ module VagrantPlugins
 
       def call_overstate
         if @config.run_overstate
+          # If verbose is on, do not duplicate a failed command's output in the error message.
+          ssh_opts = {}
+          if @config.verbose
+            ssh_opts = { error_key: :ssh_bad_exit_status_muted }
+          end
           if @config.install_master
             @machine.env.ui.info "Calling state.overstate... (this may take a while)"
             @machine.communicate.sudo("salt '*' saltutil.sync_all")
-            @machine.communicate.sudo("salt-run state.over") do |type, data|
+            @machine.communicate.sudo("salt-run state.over", ssh_opts) do |type, data|
               if @config.verbose
                 @machine.env.ui.info(data)
               end
@@ -335,16 +367,19 @@ module VagrantPlugins
 
       def call_highstate
         if @config.run_highstate
-          local=""
-          if @config.masterless
-            local=" --local"
+          # If verbose is on, do not duplicate a failed command's output in the error message.
+          ssh_opts = {}
+          if @config.verbose
+            ssh_opts = { error_key: :ssh_bad_exit_status_muted }
           end
+
           @machine.env.ui.info "Calling state.highstate... (this may take a while)"
           if @config.install_master
             unless @config.masterless?
               @machine.communicate.sudo("salt '*' saltutil.sync_all")
             end
-            @machine.communicate.sudo("salt '*' state.highstate --verbose #{local}#{get_loglevel}#{get_colorize}#{get_pillar}") do |type, data|
+            options = "#{get_masterless}#{get_loglevel}#{get_colorize}#{get_pillar}#{get_salt_args}"
+            @machine.communicate.sudo("salt '*' state.highstate --verbose#{options}", ssh_opts) do |type, data|
             if @config.verbose
                 @machine.env.ui.info(data.rstrip)
             end
@@ -355,7 +390,9 @@ module VagrantPlugins
               unless @config.masterless?
                 @machine.communicate.execute("C:\\salt\\salt-call.bat saltutil.sync_all", opts)
               end
-              @machine.communicate.execute("C:\\salt\\salt-call.bat state.highstate --retcode-passthrough #{local}#{get_loglevel}#{get_colorize}#{get_pillar}", opts) do |type, data|
+              # TODO: something equivalent to { error_key: :ssh_bad_exit_status_muted }?
+              options = "#{get_masterless}#{get_loglevel}#{get_colorize}#{get_pillar}#{get_call_args}"
+              @machine.communicate.execute("C:\\salt\\salt-call.bat state.highstate --retcode-passthrough#{options}", opts) do |type, data|
                 if @config.verbose
                   @machine.env.ui.info(data.rstrip)
                 end
@@ -364,7 +401,8 @@ module VagrantPlugins
               unless @config.masterless?
                 @machine.communicate.sudo("salt-call saltutil.sync_all")
               end
-              @machine.communicate.sudo("salt-call state.highstate --retcode-passthrough #{local}#{get_loglevel}#{get_colorize}#{get_pillar}") do |type, data|
+              options = "#{get_masterless}#{get_loglevel}#{get_colorize}#{get_pillar}#{get_call_args}"
+              @machine.communicate.sudo("salt-call state.highstate --retcode-passthrough#{options}", ssh_opts) do |type, data|
                 if @config.verbose
                   @machine.env.ui.info(data.rstrip)
                 end
@@ -393,14 +431,20 @@ module VagrantPlugins
           end
         end
 
+        # If verbose is on, do not duplicate a failed command's output in the error message.
+        ssh_opts = {}
+        if @config.verbose
+          ssh_opts = { error_key: :ssh_bad_exit_status_muted }
+        end
+
         @machine.env.ui.info "Running the following orchestrations: #{@config.orchestrations}"
         @machine.env.ui.info "Running saltutil.sync_all before orchestrating"
-        @machine.communicate.sudo("salt '*' saltutil.sync_all", &log_output)
+        @machine.communicate.sudo("salt '*' saltutil.sync_all", ssh_opts, &log_output)
 
         @config.orchestrations.each do |orchestration|
           cmd = "salt-run -l info state.orchestrate #{orchestration}"
           @machine.env.ui.info "Calling #{cmd}... (this may take a while)"
-          @machine.communicate.sudo(cmd, &log_output)
+          @machine.communicate.sudo(cmd, ssh_opts, &log_output)
         end
       end
 
