@@ -27,7 +27,7 @@ describe VagrantPlugins::CommandBox::Command::Update do
   subject { described_class.new(argv, iso_env) }
 
   before do
-    iso_env.stub(action_runner: action_runner)
+    allow(iso_env).to receive(:action_runner).and_return(action_runner)
     machine.config.vm.box = "foo"
   end
 
@@ -64,7 +64,7 @@ describe VagrantPlugins::CommandBox::Command::Update do
 
         subject.execute
 
-        expect(called).to be_false
+        expect(called).to be(false)
       end
 
       it "does update if there is an update" do
@@ -94,6 +94,7 @@ describe VagrantPlugins::CommandBox::Command::Update do
         allow(action_runner).to receive(:run) do |action, opts|
           if opts[:box_provider]
             action_called = true
+            expect(opts[:box_force]).to eq(nil)
             expect(opts[:box_url]).to eq(metadata_url.to_s)
             expect(opts[:box_provider]).to eq("virtualbox")
             expect(opts[:box_version]).to eq("1.1")
@@ -108,7 +109,7 @@ describe VagrantPlugins::CommandBox::Command::Update do
 
         subject.execute
 
-        expect(action_called).to be_true
+        expect(action_called).to be(true)
       end
 
       it "raises an error if there are multiple providers" do
@@ -162,7 +163,7 @@ describe VagrantPlugins::CommandBox::Command::Update do
 
           subject.execute
 
-          expect(action_called).to be_true
+          expect(action_called).to be(true)
         end
 
         it "raises an error if that provider doesn't exist" do
@@ -206,14 +207,14 @@ describe VagrantPlugins::CommandBox::Command::Update do
               expect(opts[:box_download_ca_cert]).to eq("foo")
               expect(opts[:box_download_ca_path]).to eq("bar")
               expect(opts[:box_client_cert]).to eq("baz")
-              expect(opts[:box_download_insecure]).to be_true
+              expect(opts[:box_download_insecure]).to be(true)
             end
 
             opts
           end
 
           subject.execute
-          expect(action_called).to be_true
+          expect(action_called).to be(true)
         end
       end
 
@@ -238,7 +239,7 @@ describe VagrantPlugins::CommandBox::Command::Update do
         box_dir = test_iso_env.box3("foo", "1.0", :virtualbox)
         box = Vagrant::Box.new(
           "foo", :virtualbox, "1.0", box_dir, metadata_url: "foo")
-        box.stub(has_update?: nil)
+        allow(box).to receive(:has_update?).and_return(nil)
         box
       end
 
@@ -249,7 +250,7 @@ describe VagrantPlugins::CommandBox::Command::Update do
       end
 
       it "doesn't update boxes if they're up-to-date" do
-        machine.stub(box: box)
+        allow(machine).to receive(:box).and_return(box)
         expect(box).to receive(:has_update?).
           with(machine.config.vm.box_version,
                {download_options:
@@ -285,7 +286,7 @@ describe VagrantPlugins::CommandBox::Command::Update do
           RAW
         }
 
-        before { machine.stub(box: box) }
+        before { allow(machine).to receive(:box).and_return(box) }
 
         it "updates boxes" do
           expect(box).to receive(:has_update?).
@@ -295,7 +296,7 @@ describe VagrantPlugins::CommandBox::Command::Update do
                     insecure: false}}).
             and_return([md, md.version("1.1"), md.version("1.1").provider("virtualbox")])
 
-          expect(action_runner).to receive(:run).with { |action, opts|
+          expect(action_runner).to receive(:run).with(any_args) { |action, opts|
             expect(opts[:box_url]).to eq(box.metadata_url)
             expect(opts[:box_provider]).to eq("virtualbox")
             expect(opts[:box_version]).to eq("1.1")
@@ -322,11 +323,11 @@ describe VagrantPlugins::CommandBox::Command::Update do
                       insecure: false}}).
               and_return([md, md.version("1.1"), md.version("1.1").provider("virtualbox")])
 
-            expect(action_runner).to receive(:run).with { |action, opts|
+            expect(action_runner).to receive(:run).with(any_args) { |action, opts|
               expect(opts[:box_download_ca_cert]).to eq("oof")
               expect(opts[:box_download_ca_path]).to eq("rab")
               expect(opts[:box_client_cert]).to eq("zab")
-              expect(opts[:box_download_insecure]).to be_false
+              expect(opts[:box_download_insecure]).to be(false)
               true
             }
 
@@ -345,11 +346,32 @@ describe VagrantPlugins::CommandBox::Command::Update do
                 and_return([md, md.version("1.1"),
                             md.version("1.1").provider("virtualbox")])
 
-              expect(action_runner).to receive(:run).with { |action, opts|
+              expect(action_runner).to receive(:run).with(any_args) { |action, opts|
                 expect(opts[:box_download_ca_cert]).to eq("foo")
                 expect(opts[:box_download_ca_path]).to eq("bar")
                 expect(opts[:box_client_cert]).to eq("baz")
-                expect(opts[:box_download_insecure]).to be_true
+                expect(opts[:box_download_insecure]).to be(true)
+                true
+              }
+
+              subject.execute
+            end
+          end
+
+          context "force flag is specified on the command line" do
+            let(:argv) { ["--force"].concat(download_options) }
+
+            it "passes force through to action_box_add as true" do
+              expect(box).to receive(:has_update?).
+                with(machine.config.vm.box_version,
+                     {download_options:
+                       {ca_cert: "foo", ca_path: "bar", client_cert: "baz",
+                        insecure: true}}).
+                and_return([md, md.version("1.1"),
+                            md.version("1.1").provider("virtualbox")])
+
+              expect(action_runner).to receive(:run).with(any_args) { |action, opts|
+                expect(opts[:box_force]).to be(true)
                 true
               }
 
