@@ -46,11 +46,11 @@ describe VagrantPlugins::DockerProvider::Config do
     its(:expose) { should eq([]) }
     its(:cmd) { should eq([]) }
     its(:env) { should eq({}) }
-    its(:force_host_vm) { should be_false }
+    its(:force_host_vm) { should be(false) }
     its(:host_vm_build_dir_options) { should be_nil }
     its(:image) { should be_nil }
     its(:name) { should be_nil }
-    its(:privileged) { should be_false }
+    its(:privileged) { should be(false) }
     its(:stop_timeout) { should eq(1) }
     its(:vagrant_machine) { should be_nil }
     its(:vagrant_vagrantfile) { should be_nil }
@@ -63,8 +63,8 @@ describe VagrantPlugins::DockerProvider::Config do
 
   before do
     # By default lets be Linux for validations
-    Vagrant::Util::Platform.stub(linux: true)
-    Vagrant::Util::Platform.stub(linux?: true)
+    allow(Vagrant::Util::Platform).to receive(:linux).and_return(true)
+    allow(Vagrant::Util::Platform).to receive(:linux?).and_return(true)
   end
 
   it "should be invalid if both build dir and image are set" do
@@ -89,6 +89,25 @@ describe VagrantPlugins::DockerProvider::Config do
     end
   end
 
+  describe "#compose" do
+    before do
+      valid_defaults
+    end
+
+    it "should be valid when enabled" do
+      subject.compose = true
+      subject.finalize!
+      assert_valid
+    end
+
+    it "should be invalid when force_host_vm is enabled" do
+      subject.compose = true
+      subject.force_host_vm = true
+      subject.finalize!
+      assert_invalid
+    end
+  end
+
   describe "#create_args" do
     before do
       valid_defaults
