@@ -41,7 +41,7 @@ describe VagrantPlugins::FTPPush::Push do
       end
       @server.start
 
-      @dir = temporary_dir
+      @dir = Dir.mktmpdir("vagrant-ftp-push")
       FileUtils.touch("#{@dir}/.hidden.rb")
       FileUtils.touch("#{@dir}/application.rb")
       FileUtils.touch("#{@dir}/config.rb")
@@ -51,6 +51,7 @@ describe VagrantPlugins::FTPPush::Push do
     end
 
     after(:all) do
+      FileUtils.rm_rf(@dir)
       @server.stop
     end
 
@@ -109,7 +110,7 @@ describe VagrantPlugins::FTPPush::Push do
 
   describe "#all_files" do
     before(:all) do
-      @dir = Dir.mktmpdir
+      @dir = Dir.mktmpdir("vagrant-ftp-push-push-all-files")
 
       FileUtils.touch("#{@dir}/.hidden.rb")
       FileUtils.touch("#{@dir}/application.rb")
@@ -151,9 +152,9 @@ describe VagrantPlugins::FTPPush::Push do
     end
   end
 
-  describe "includes_files" do
+  describe "#includes_files" do
     before(:all) do
-      @dir = Dir.mktmpdir
+      @dir = Dir.mktmpdir("vagrant-ftp-push-includes-files")
 
       FileUtils.touch("#{@dir}/.hidden.rb")
       FileUtils.touch("#{@dir}/application.rb")
