@@ -81,7 +81,7 @@ describe Vagrant::Action::Builtin::BoxAdd, :skip_windows do
   end
 
   before do
-    box_collection.stub(find: nil)
+    allow(box_collection).to receive(:find).and_return(nil)
   end
 
   context "with box file directly" do
@@ -91,7 +91,7 @@ describe Vagrant::Action::Builtin::BoxAdd, :skip_windows do
       env[:box_name] = "foo"
       env[:box_url] = box_path.to_s
 
-      expect(box_collection).to receive(:add).with { |path, name, version, **opts|
+      expect(box_collection).to receive(:add).with(any_args) { |path, name, version, **opts|
         expect(checksum(path)).to eq(checksum(box_path))
         expect(name).to eq("foo")
         expect(version).to eq("0")
@@ -113,7 +113,7 @@ describe Vagrant::Action::Builtin::BoxAdd, :skip_windows do
         box_path.to_s,
       ]
 
-      expect(box_collection).to receive(:add).with { |path, name, version, **opts|
+      expect(box_collection).to receive(:add).with(any_args) { |path, name, version, **opts|
         expect(checksum(path)).to eq(checksum(box_path))
         expect(name).to eq("foo")
         expect(version).to eq("0")
@@ -132,7 +132,7 @@ describe Vagrant::Action::Builtin::BoxAdd, :skip_windows do
         env[:box_name] = "foo"
         env[:box_url] = "http://127.0.0.1:#{port}/#{box_path.basename}"
 
-        expect(box_collection).to receive(:add).with { |path, name, version, **opts|
+        expect(box_collection).to receive(:add).with(any_args) { |path, name, version, **opts|
           expect(checksum(path)).to eq(checksum(box_path))
           expect(name).to eq("foo")
           expect(version).to eq("0")
@@ -152,7 +152,7 @@ describe Vagrant::Action::Builtin::BoxAdd, :skip_windows do
         env[:box_name] = "foo"
         env[:box_url] = "ftp://127.0.0.1:#{port}/#{box_path.basename}"
 
-        expect(box_collection).to receive(:add).with { |path, name, version, **opts|
+        expect(box_collection).to receive(:add).with(any_args) { |path, name, version, **opts|
           expect(checksum(path)).to eq(checksum(box_path))
           expect(name).to eq("foo")
           expect(version).to eq("0")
@@ -267,8 +267,8 @@ describe Vagrant::Action::Builtin::BoxAdd, :skip_windows do
       env[:box_url] = box_path.to_s
       env[:box_provider] = "virtualbox"
 
-      box_collection.stub(find: box)
-      expect(box_collection).to receive(:add).with { |path, name, version, **opts|
+      allow(box_collection).to receive(:find).and_return(box)
+      expect(box_collection).to receive(:add).with(any_args) { |path, name, version, **opts|
         expect(checksum(path)).to eq(checksum(box_path))
         expect(name).to eq("foo")
         expect(version).to eq("0")
@@ -279,6 +279,76 @@ describe Vagrant::Action::Builtin::BoxAdd, :skip_windows do
 
       subject.call(env)
     end
+
+    context "with a box name accidentally set as a URL" do
+      it "displays a warning to the user" do
+        box_path = iso_env.box2_file(:virtualbox)
+        port = 9999
+
+        box_url_name = "http://127.0.0.1:#{port}/#{box_path.basename}"
+        env[:box_name] = box_url_name
+
+        expect(box_collection).to receive(:add).with(any_args) { |path, name, version, **opts|
+          expect(name).to eq(box_url_name)
+          expect(version).to eq("0")
+          expect(opts[:metadata_url]).to be_nil
+          true
+        }.and_return(box)
+
+        expect(app).to receive(:call).with(env)
+
+        expect(env[:ui]).to receive(:warn)
+          .with(/It looks like you attempted to add a box with a URL for the name/)
+
+        subject.call(env)
+      end
+    end
+
+    context "with a box name containing invalid URI characters" do
+      it "should not raise an error" do
+        box_path = iso_env.box2_file(:virtualbox)
+        box_url_name = "box name with spaces"
+        env[:box_name] = box_url_name
+
+        expect(box_collection).to receive(:add).with(any_args) { |path, name, version, **opts|
+          expect(name).to eq(box_url_name)
+          expect(version).to eq("0")
+          expect(opts[:metadata_url]).to be_nil
+          true
+        }.and_return(box)
+
+        expect(app).to receive(:call).with(env)
+
+        subject.call(env)
+      end
+    end
+
+    context "with URL containing credentials" do
+      let(:username){ "box-username" }
+      let(:password){ "box-password" }
+
+      it "scrubs credentials in output" do
+        box_path = iso_env.box2_file(:virtualbox)
+        with_web_server(box_path) do |port|
+          env[:box_name] = "foo"
+          env[:box_url] = "http://#{username}:#{password}@127.0.0.1:#{port}/#{box_path.basename}"
+
+          expect(box_collection).to receive(:add).with(any_args) { |path, name, version, **opts|
+            expect(checksum(path)).to eq(checksum(box_path))
+            expect(name).to eq("foo")
+            expect(version).to eq("0")
+            expect(opts[:metadata_url]).to be_nil
+            true
+          }.and_return(box)
+
+          allow(env[:ui]).to receive(:detail)
+          expect(env[:ui]).to receive(:detail).with(%r{.*http://(?!#{username}).+?:(?!#{password}).+?@127\.0\.0\.1:#{port}/#{box_path.basename}.*})
+          expect(app).to receive(:call).with(env)
+
+          subject.call(env)
+        end
+      end
+    end
   end
 
   context "with box metadata" do
@@ -311,7 +381,7 @@ describe Vagrant::Action::Builtin::BoxAdd, :skip_windows do
       with_web_server(md_path) do |port|
         env[:box_url] = "http://127.0.0.1:#{port}/#{md_path.basename}"
 
-        expect(box_collection).to receive(:add).with { |path, name, version, **opts|
+        expect(box_collection).to receive(:add).with(any_args) { |path, name, version, **opts|
           expect(name).to eq("foo/bar")
           expect(version).to eq("0.7")
           expect(checksum(path)).to eq(checksum(box_path))
@@ -356,7 +426,7 @@ describe Vagrant::Action::Builtin::BoxAdd, :skip_windows do
       with_web_server(md_path, **opts) do |port|
         env[:box_url] = "http://127.0.0.1:#{port}/#{md_path.basename}"
 
-        expect(box_collection).to receive(:add).with { |path, name, version, **opts|
+        expect(box_collection).to receive(:add).with(any_args) { |path, name, version, **opts|
           expect(name).to eq("foo/bar")
           expect(version).to eq("0.7")
           expect(checksum(path)).to eq(checksum(box_path))
@@ -401,7 +471,7 @@ describe Vagrant::Action::Builtin::BoxAdd, :skip_windows do
         url = "http://127.0.0.1:#{port}"
         env[:box_url] = "mitchellh/precise64.json"
 
-        expect(box_collection).to receive(:add).with { |path, name, version, **opts|
+        expect(box_collection).to receive(:add).with(any_args) { |path, name, version, **opts|
           expect(name).to eq("mitchellh/precise64")
           expect(version).to eq("0.7")
           expect(checksum(path)).to eq(checksum(box_path))
@@ -452,7 +522,7 @@ describe Vagrant::Action::Builtin::BoxAdd, :skip_windows do
         env[:box_url] = "mitchellh/precise64.json"
         env[:box_server_url] = url
 
-        expect(box_collection).to receive(:add).with { |path, name, version, **opts|
+        expect(box_collection).to receive(:add).with(any_args) { |path, name, version, **opts|
           expect(name).to eq("mitchellh/precise64")
           expect(version).to eq("0.7")
           expect(checksum(path)).to eq(checksum(box_path))
@@ -513,7 +583,7 @@ describe Vagrant::Action::Builtin::BoxAdd, :skip_windows do
           end
         end
 
-        expect(box_collection).to receive(:add).with { |path, name, version, **opts|
+        expect(box_collection).to receive(:add).with(any_args) { |path, name, version, **opts|
           expect(name).to eq("foo/bar")
           expect(version).to eq("0.7")
           expect(checksum(path)).to eq(checksum(box_path))
@@ -558,7 +628,7 @@ describe Vagrant::Action::Builtin::BoxAdd, :skip_windows do
       with_web_server(md_path) do |port|
         env[:box_url] = "http://127.0.0.1:#{port}/#{md_path.basename}"
 
-        expect(box_collection).to receive(:add).with { |path, name, version, **opts|
+        expect(box_collection).to receive(:add).with(any_args) { |path, name, version, **opts|
           expect(name).to eq("foo/bar")
           expect(version).to eq("0.7")
           expect(checksum(path)).to eq(checksum(box_path))
@@ -617,7 +687,7 @@ describe Vagrant::Action::Builtin::BoxAdd, :skip_windows do
       expect(box_collection).to receive(:add).never
       expect(app).to receive(:call).never
 
-      Vagrant.stub(server_url: nil)
+      allow(Vagrant).to receive(:server_url).and_return(nil)
 
       expect { subject.call(env) }.
         to raise_error(Vagrant::Errors::BoxServerNotSet)
@@ -702,7 +772,7 @@ describe Vagrant::Action::Builtin::BoxAdd, :skip_windows do
       end
 
       env[:box_url] = tf.path
-      expect(box_collection).to receive(:add).with { |path, name, version, **opts|
+      expect(box_collection).to receive(:add).with(any_args) { |path, name, version, **opts|
         expect(checksum(path)).to eq(checksum(box_path))
         expect(name).to eq("foo/bar")
         expect(version).to eq("0.7")
@@ -746,7 +816,7 @@ describe Vagrant::Action::Builtin::BoxAdd, :skip_windows do
 
       env[:box_url] = tf.path
       env[:box_provider] = "vmware"
-      expect(box_collection).to receive(:add).with { |path, name, version, **opts|
+      expect(box_collection).to receive(:add).with(any_args) { |path, name, version, **opts|
         expect(checksum(path)).to eq(checksum(box_path))
         expect(name).to eq("foo/bar")
         expect(version).to eq("0.7")
@@ -795,7 +865,7 @@ describe Vagrant::Action::Builtin::BoxAdd, :skip_windows do
 
       env[:box_url] = tf.path
       env[:box_provider] = "vmware"
-      expect(box_collection).to receive(:add).with { |path, name, version, **opts|
+      expect(box_collection).to receive(:add).with(any_args) { |path, name, version, **opts|
         expect(checksum(path)).to eq(checksum(box_path))
         expect(name).to eq("foo/bar")
         expect(version).to eq("0.7")
@@ -835,7 +905,7 @@ describe Vagrant::Action::Builtin::BoxAdd, :skip_windows do
 
       env[:box_url] = tf.path
       env[:box_version] = "~> 0.1"
-      expect(box_collection).to receive(:add).with { |path, name, version, **opts|
+      expect(box_collection).to receive(:add).with(any_args) { |path, name, version, **opts|
         expect(checksum(path)).to eq(checksum(box_path))
         expect(name).to eq("foo/bar")
         expect(version).to eq("0.5")
@@ -880,7 +950,7 @@ describe Vagrant::Action::Builtin::BoxAdd, :skip_windows do
       env[:box_url] = tf.path
       env[:box_provider] = "vmware"
       env[:box_version] = "~> 0.1"
-      expect(box_collection).to receive(:add).with { |path, name, version, **opts|
+      expect(box_collection).to receive(:add).with(any_args) { |path, name, version, **opts|
         expect(checksum(path)).to eq(checksum(box_path))
         expect(name).to eq("foo/bar")
         expect(version).to eq("0.5")
@@ -928,7 +998,7 @@ describe Vagrant::Action::Builtin::BoxAdd, :skip_windows do
 
       env[:box_url] = tf.path
       env[:box_provider] = ["virtualbox", "vmware"]
-      expect(box_collection).to receive(:add).with { |path, name, version, **opts|
+      expect(box_collection).to receive(:add).with(any_args) { |path, name, version, **opts|
         expect(checksum(path)).to eq(checksum(box_path))
         expect(name).to eq("foo/bar")
         expect(version).to eq("0.7")
@@ -976,7 +1046,7 @@ describe Vagrant::Action::Builtin::BoxAdd, :skip_windows do
 
       expect(env[:ui]).to receive(:ask).and_return("1")
 
-      expect(box_collection).to receive(:add).with { |path, name, version, **opts|
+      expect(box_collection).to receive(:add).with(any_args) { |path, name, version, **opts|
         expect(checksum(path)).to eq(checksum(box_path))
         expect(name).to eq("foo/bar")
         expect(version).to eq("0.7")
@@ -1151,12 +1221,12 @@ describe Vagrant::Action::Builtin::BoxAdd, :skip_windows do
 
       env[:box_force] = true
       env[:box_url] = tf.path
-      box_collection.stub(find: box)
-      expect(box_collection).to receive(:add).with { |path, name, version, **opts|
+      allow(box_collection).to receive(:find).and_return(box)
+      expect(box_collection).to receive(:add).with(any_args) { |path, name, version, **opts|
         expect(checksum(path)).to eq(checksum(box_path))
         expect(name).to eq("foo/bar")
         expect(version).to eq("0.7")
-        expect(opts[:force]).to be_true
+        expect(opts[:force]).to be(true)
         expect(opts[:metadata_url]).to eq("file://#{tf.path}")
         true
       }.and_return(box)
