@@ -31,8 +31,8 @@ describe Vagrant::Environment do
 
     before do
       m = Vagrant.plugin("2").manager
-      m.stub(hosts: plugin_hosts)
-      m.stub(host_capabilities: plugin_host_caps)
+      allow(m).to receive(:hosts).and_return(plugin_hosts)
+      allow(m).to receive(:host_capabilities).and_return(plugin_host_caps)
 
       # Detect the host
       env.vagrantfile <<-VF
@@ -48,8 +48,8 @@ describe Vagrant::Environment do
     it "should return whether it can install or not" do
       plugin_host_caps[:foo] = { provider_install_foo: Class }
 
-      expect(subject.can_install_provider?(:foo)).to be_true
-      expect(subject.can_install_provider?(:bar)).to be_false
+      expect(subject.can_install_provider?(:foo)).to be(true)
+      expect(subject.can_install_provider?(:bar)).to be(false)
     end
   end
 
@@ -67,6 +67,13 @@ describe Vagrant::Environment do
     end
   end
 
+  describe "#gems_path" do
+    it "is set to Vagrant::Bundler defined path" do
+      instance = described_class.new
+      expect(instance.gems_path).to eq(Vagrant::Bundler.instance.plugin_gem_path)
+    end
+  end
+
   describe "#home_path" do
     it "is set to the home path given" do
       Dir.mktmpdir("vagrant-test-env-home-path-given") do |dir|
@@ -153,7 +160,8 @@ describe Vagrant::Environment do
 
       it "moves the boxes into the new directory structure" do
         # Kind of hacky but avoids two instantiations of BoxCollection
-        Vagrant::Environment.any_instance.stub(boxes: double("boxes"))
+        allow(Vagrant::Environment).to receive(:boxes)
+          .and_return(double("boxes"))
 
         collection = double("collection")
         expect(Vagrant::BoxCollection).to receive(:new).with(
@@ -170,8 +178,8 @@ describe Vagrant::Environment do
 
     before do
       m = Vagrant.plugin("2").manager
-      m.stub(hosts: plugin_hosts)
-      m.stub(host_capabilities: plugin_host_caps)
+      allow(m).to receive(:hosts).and_return(plugin_hosts)
+      allow(m).to receive(:host_capabilities).and_return(plugin_host_caps)
     end
 
     it "should default to some host even if there are none" do
@@ -195,7 +203,7 @@ describe Vagrant::Environment do
       plugin_host_caps[:foo] = { bar: Class }
 
       result = subject.host
-      expect(result.capability?(:bar)).to be_true
+      expect(result.capability?(:bar)).to be(true)
     end
 
     it "should attempt to detect a host if host is :detect" do
@@ -209,7 +217,7 @@ describe Vagrant::Environment do
       plugin_host_caps[:foo] = { bar: Class }
 
       result = subject.host
-      expect(result.capability?(:bar)).to be_true
+      expect(result.capability?(:bar)).to be(true)
     end
 
     it "should use an exact host if specified" do
@@ -224,7 +232,7 @@ describe Vagrant::Environment do
       plugin_host_caps[:foo] = { bar: Class }
 
       result = subject.host
-      expect(result.capability?(:bar)).to be_true
+      expect(result.capability?(:bar)).to be(true)
     end
 
     it "should raise an error if an exact match was specified but not found" do
@@ -263,7 +271,7 @@ describe Vagrant::Environment do
         end
       end
 
-      expect(raised).to be_true
+      expect(raised).to be(true)
     end
 
     it "allows nested locks on the same environment" do
@@ -275,7 +283,7 @@ describe Vagrant::Environment do
         end
       end
 
-      expect(success).to be_true
+      expect(success).to be(true)
     end
 
     it "cleans up all lock files" do
@@ -634,8 +642,8 @@ VF
       klass = double("machine_index")
       stub_const("Vagrant::MachineIndex", klass)
 
-      klass.should_receive(:new).with do |path|
-        expect(path.to_s.start_with?(subject.home_path.to_s)).to be_true
+      expect(klass).to receive(:new).with(any_args) do |path|
+        expect(path.to_s.start_with?(subject.home_path.to_s)).to be(true)
         true
       end
 
@@ -752,7 +760,7 @@ VF
 
     before do
       m = Vagrant.plugin("2").manager
-      m.stub(providers: plugin_providers)
+      allow(m).to receive(:providers).and_return(plugin_providers)
     end
 
     it "is the highest matching usable provider" do
@@ -761,7 +769,8 @@ VF
       plugin_providers[:baz] = [provider_usable_class(true), { priority: 2 }]
       plugin_providers[:boom] = [provider_usable_class(true), { priority: 3 }]
 
-      with_temp_env("VAGRANT_DEFAULT_PROVIDER" => nil) do
+      with_temp_env("VAGRANT_DEFAULT_PROVIDER" => nil,
+                    "VAGRANT_PREFERRED_PROVIDERS" => nil) do
         expect(subject.default_provider).to eq(:bar)
       end
     end
@@ -772,7 +781,8 @@ VF
         provider_usable_class(true), { defaultable: false, priority: 7 }]
       plugin_providers[:baz] = [provider_usable_class(true), { priority: 2 }]
 
-      with_temp_env("VAGRANT_DEFAULT_PROVIDER" => nil) do
+      with_temp_env("VAGRANT_DEFAULT_PROVIDER" => nil,
+                    "VAGRANT_PREFERRED_PROVIDERS" => nil) do
         expect(subject.default_provider).to eq(:foo)
       end
     end
@@ -783,7 +793,8 @@ VF
       plugin_providers[:baz] = [provider_usable_class(true), { priority: 2 }]
       plugin_providers[:boom] = [provider_usable_class(true), { priority: 3 }]
 
-      with_temp_env("VAGRANT_DEFAULT_PROVIDER" => nil) do
+      with_temp_env("VAGRANT_DEFAULT_PROVIDER" => nil,
+                    "VAGRANT_PREFERRED_PROVIDERS" => nil) do
         expect(subject.default_provider(exclude: [:bar, :foo])).to eq(:boom)
       end
     end
@@ -794,7 +805,8 @@ VF
       plugin_providers[:baz] = [provider_usable_class(true), { priority: 2 }]
       plugin_providers[:boom] = [provider_usable_class(true), { priority: 3 }]
 
-      with_temp_env("VAGRANT_DEFAULT_PROVIDER" => "baz") do
+      with_temp_env("VAGRANT_DEFAULT_PROVIDER" => "baz",
+                    "VAGRANT_PREFERRED_PROVIDERS" => nil) do
         expect(subject.default_provider).to eq(:baz)
       end
     end
@@ -804,7 +816,8 @@ VF
       plugin_providers[:foo] = [provider_usable_class(true), { priority: 5 }]
       plugin_providers[:bar] = [provider_usable_class(true), { priority: 7 }]
 
-      with_temp_env("VAGRANT_DEFAULT_PROVIDER" => "baz") do
+      with_temp_env("VAGRANT_DEFAULT_PROVIDER" => "baz",
+                    "VAGRANT_PREFERRED_PROVIDERS" => nil) do
         expect(subject.default_provider).to eq(:baz)
       end
     end
@@ -814,7 +827,8 @@ VF
       plugin_providers[:foo] = [provider_usable_class(true), { priority: 5 }]
       plugin_providers[:bar] = [provider_usable_class(true), { priority: 7 }]
 
-      with_temp_env("VAGRANT_DEFAULT_PROVIDER" => "baz") do
+      with_temp_env("VAGRANT_DEFAULT_PROVIDER" => "baz",
+                    "VAGRANT_PREFERRED_PROVIDERS" => nil) do
         expect(subject.default_provider(force_default: false)).to eq(:bar)
       end
     end
@@ -824,7 +838,8 @@ VF
       plugin_providers[:foo] = [provider_usable_class(true), { priority: 5 }]
       plugin_providers[:bar] = [provider_usable_class(true), { priority: 7 }]
 
-      with_temp_env("VAGRANT_DEFAULT_PROVIDER" => "baz") do
+      with_temp_env("VAGRANT_DEFAULT_PROVIDER" => "baz",
+                    "VAGRANT_PREFERRED_PROVIDERS" => nil) do
         expect(subject.default_provider(force_default: false)).to eq(:baz)
       end
     end
@@ -834,7 +849,8 @@ VF
       plugin_providers[:bar] = [provider_usable_class(true), { priority: 7 }]
       plugin_providers[:baz] = [provider_usable_class(true), { priority: 8 }]
 
-      with_temp_env("VAGRANT_DEFAULT_PROVIDER" => "baz") do
+      with_temp_env("VAGRANT_DEFAULT_PROVIDER" => "baz",
+                    "VAGRANT_PREFERRED_PROVIDERS" => nil) do
         expect(subject.default_provider(
           exclude: [:baz], force_default: false)).to eq(:bar)
       end
@@ -845,12 +861,29 @@ VF
       plugin_providers[:bar] = [provider_usable_class(false), { priority: 5 }]
       plugin_providers[:baz] = [provider_usable_class(false), { priority: 5 }]
 
-      with_temp_env("VAGRANT_DEFAULT_PROVIDER" => nil) do
+      with_temp_env("VAGRANT_DEFAULT_PROVIDER" => nil,
+                    "VAGRANT_PREFERRED_PROVIDERS" => nil) do
         expect { subject.default_provider }.to raise_error(
           Vagrant::Errors::NoDefaultProvider)
       end
     end
 
+    it "is the provider in the Vagrantfile that is preferred and usable" do
+      subject.vagrantfile.config.vm.provider "foo"
+      subject.vagrantfile.config.vm.provider "bar"
+      subject.vagrantfile.config.vm.finalize!
+
+      plugin_providers[:foo] = [provider_usable_class(true), { priority: 5 }]
+      plugin_providers[:bar] = [provider_usable_class(true), { priority: 7 }]
+      plugin_providers[:baz] = [provider_usable_class(true), { priority: 2 }]
+      plugin_providers[:boom] = [provider_usable_class(true), { priority: 3 }]
+
+      with_temp_env("VAGRANT_DEFAULT_PROVIDER" => nil,
+                    "VAGRANT_PREFERRED_PROVIDERS" => 'baz,bar') do
+        expect(subject.default_provider).to eq(:bar)
+      end
+    end
+
     it "is the provider in the Vagrantfile that is usable" do
       subject.vagrantfile.config.vm.provider "foo"
       subject.vagrantfile.config.vm.provider "bar"
@@ -861,7 +894,8 @@ VF
       plugin_providers[:baz] = [provider_usable_class(true), { priority: 2 }]
       plugin_providers[:boom] = [provider_usable_class(true), { priority: 3 }]
 
-      with_temp_env("VAGRANT_DEFAULT_PROVIDER" => nil) do
+      with_temp_env("VAGRANT_DEFAULT_PROVIDER" => nil,
+                    "VAGRANT_PREFERRED_PROVIDERS" => nil) do
         expect(subject.default_provider).to eq(:foo)
       end
     end
@@ -873,7 +907,8 @@ VF
       plugin_providers[:foo] = [provider_usable_class(true), { priority: 5 }]
       plugin_providers[:bar] = [provider_usable_class(true), { priority: 7 }]
 
-      with_temp_env("VAGRANT_DEFAULT_PROVIDER" => nil) do
+      with_temp_env("VAGRANT_DEFAULT_PROVIDER" => nil,
+                    "VAGRANT_PREFERRED_PROVIDERS" => nil) do
         expect(subject.default_provider).to eq(:foo)
       end
     end
@@ -885,11 +920,27 @@ VF
       plugin_providers[:foo] = [provider_usable_class(true), { priority: 7 }]
       plugin_providers[:bar] = [provider_usable_class(true), { priority: 5 }]
 
-      with_temp_env("VAGRANT_DEFAULT_PROVIDER" => nil) do
+      with_temp_env("VAGRANT_DEFAULT_PROVIDER" => nil,
+                    "VAGRANT_PREFERRED_PROVIDERS" => nil) do
         expect(subject.default_provider).to eq(:bar)
       end
     end
 
+    it "is the preferred usable provider outside the Vagrantfile" do
+      subject.vagrantfile.config.vm.provider "foo"
+      subject.vagrantfile.config.vm.finalize!
+
+      plugin_providers[:foo] = [provider_usable_class(false), { priority: 5 }]
+      plugin_providers[:bar] = [provider_usable_class(true), { priority: 7 }]
+      plugin_providers[:baz] = [provider_usable_class(true), { priority: 2 }]
+      plugin_providers[:boom] = [provider_usable_class(true), { priority: 3 }]
+
+      with_temp_env("VAGRANT_DEFAULT_PROVIDER" => nil,
+                    "VAGRANT_PREFERRED_PROVIDERS" => 'boom,baz') do
+        expect(subject.default_provider).to eq(:boom)
+      end
+    end
+
     it "is the highest usable provider outside the Vagrantfile" do
       subject.vagrantfile.config.vm.provider "foo"
       subject.vagrantfile.config.vm.finalize!
@@ -899,7 +950,8 @@ VF
       plugin_providers[:baz] = [provider_usable_class(true), { priority: 2 }]
       plugin_providers[:boom] = [provider_usable_class(true), { priority: 3 }]
 
-      with_temp_env("VAGRANT_DEFAULT_PROVIDER" => nil) do
+      with_temp_env("VAGRANT_DEFAULT_PROVIDER" => nil,
+                    "VAGRANT_PREFERRED_PROVIDERS" => nil) do
         expect(subject.default_provider).to eq(:bar)
       end
     end
@@ -916,7 +968,8 @@ VF
       plugin_providers[:baz] = [provider_usable_class(true), { priority: 2 }]
       plugin_providers[:boom] = [provider_usable_class(true), { priority: 3 }]
 
-      with_temp_env("VAGRANT_DEFAULT_PROVIDER" => nil) do
+      with_temp_env("VAGRANT_DEFAULT_PROVIDER" => nil,
+                    "VAGRANT_PREFERRED_PROVIDERS" => nil) do
         expect(subject.default_provider(machine: :sub)).to eq(:bar)
       end
     end
@@ -933,7 +986,7 @@ VF
         Dir.chdir(temp_dir) do
           instance = described_class.new(local_data_path: "foo")
           expect(instance.local_data_path).to eq(instance.cwd.join("foo"))
-          expect(File.exist?(instance.local_data_path)).to be_false
+          expect(File.exist?(instance.local_data_path)).to be(false)
         end
       end
     end
@@ -1023,6 +1076,16 @@ VF
       end
     end
 
+    context "with environmental variable VAGRANT_DOTFILE_PATH set with tilde" do
+      it "is set relative to the user's home directory" do
+        with_temp_env("VAGRANT_DOTFILE_PATH" => "~/.vagrant") do
+          instance = env.create_vagrant_env
+          expect(instance.cwd).to eq(env.workdir)
+          expect(instance.local_data_path.to_s).to eq(File.join(Dir.home, ".vagrant"))
+        end
+      end
+    end
+
     describe "upgrading V1 dotfiles" do
       let(:v1_dotfile_tempfile) do
         Tempfile.new("vagrant-upgrade-dotfile").tap do |f|
@@ -1187,7 +1250,7 @@ VF
 
       env = environment.create_vagrant_env
       env.push("foo")
-      expect(push_class.pushed?).to be_true
+      expect(push_class.pushed?).to be(true)
     end
   end
 
@@ -1195,7 +1258,7 @@ VF
     it "should call the action runner with the proper hook" do
       hook_name = :foo
 
-      expect(instance.action_runner).to receive(:run).with { |callable, env|
+      expect(instance.action_runner).to receive(:run).with(any_args) { |callable, env|
         expect(env[:action_name]).to eq(hook_name)
       }
 
@@ -1217,7 +1280,7 @@ VF
     end
 
     it "should allow passing in custom data" do
-      expect(instance.action_runner).to receive(:run).with { |callable, env|
+      expect(instance.action_runner).to receive(:run).with(any_args) { |callable, env|
         expect(env[:foo]).to eq(:bar)
       }
 
@@ -1225,7 +1288,7 @@ VF
     end
 
     it "should allow passing a custom callable" do
-      expect(instance.action_runner).to receive(:run).with { |callable, env|
+      expect(instance.action_runner).to receive(:run).with(any_args) { |callable, env|
         expect(callable).to eq(:what)
       }
 
