@@ -4,7 +4,7 @@ require "pathname"
 require "vagrant/plugin"
 require "vagrant/plugin/manager"
 require "vagrant/plugin/state_file"
-
+require "vagrant/util/deep_merge"
 require File.expand_path("../../../base", __FILE__)
 
 describe Vagrant::Plugin::Manager do
@@ -21,7 +21,7 @@ describe Vagrant::Plugin::Manager do
   end
 
   before do
-    Vagrant::Bundler.stub(instance: bundler)
+    allow(Vagrant::Bundler).to receive(:instance).and_return(bundler)
   end
 
   subject { described_class.new(path) }
@@ -30,9 +30,9 @@ describe Vagrant::Plugin::Manager do
     it "installs the plugin and adds it to the state file" do
       specs = Array.new(5) { Gem::Specification.new }
       specs[3].name = "foo"
-      expect(bundler).to receive(:install).once.with { |plugins, local|
+      expect(bundler).to receive(:install).once.with(any_args) { |plugins, local|
         expect(plugins).to have_key("foo")
-        expect(local).to be_false
+        expect(local).to be(false)
       }.and_return(specs)
       expect(bundler).to receive(:clean)
 
@@ -92,10 +92,10 @@ describe Vagrant::Plugin::Manager do
       end
 
       it "installs a version with constraints" do
-        expect(bundler).to receive(:install).once.with { |plugins, local|
+        expect(bundler).to receive(:install).once.with(any_args) { |plugins, local|
           expect(plugins).to have_key("foo")
           expect(plugins["foo"]["gem_version"]).to eql(">= 0.1.0")
-          expect(local).to be_false
+          expect(local).to be(false)
         }.and_return(specs)
         expect(bundler).to receive(:clean)
 
@@ -107,10 +107,10 @@ describe Vagrant::Plugin::Manager do
       end
 
       it "installs with an exact version but doesn't constrain" do
-        expect(bundler).to receive(:install).once.with { |plugins, local|
+        expect(bundler).to receive(:install).once.with(any_args) { |plugins, local|
           expect(plugins).to have_key("foo")
           expect(plugins["foo"]["gem_version"]).to eql("0.1.0")
-          expect(local).to be_false
+          expect(local).to be(false)
         }.and_return(specs)
         expect(bundler).to receive(:clean)
 
@@ -152,7 +152,7 @@ describe Vagrant::Plugin::Manager do
       before do
         systems_path.unlink
 
-        described_class.stub(system_plugins_file: systems_path)
+        allow(described_class).to receive(:system_plugins_file).and_return(systems_path)
 
         sf = Vagrant::Plugin::StateFile.new(systems_path)
         sf.add_plugin("foo", version: "0.2.0")
@@ -170,7 +170,7 @@ describe Vagrant::Plugin::Manager do
         subject.uninstall_plugin("bar")
 
         plugins = subject.installed_plugins
-        expect(plugins["foo"]["system"]).to be_true
+        expect(plugins["foo"]["system"]).to be(true)
       end
 
       it "raises an error if uninstalling a system gem" do
@@ -230,7 +230,7 @@ describe Vagrant::Plugin::Manager do
       before do
         systems_path.unlink
 
-        described_class.stub(system_plugins_file: systems_path)
+        allow(described_class).to receive(:system_plugins_file).and_return(systems_path)
 
         sf = Vagrant::Plugin::StateFile.new(systems_path)
         sf.add_plugin("foo", version: "0.2.0")
@@ -243,9 +243,9 @@ describe Vagrant::Plugin::Manager do
           expect(plugins.length).to eql(2)
           expect(plugins).to have_key("foo")
           expect(plugins["foo"]["gem_version"]).to eq("0.1.0")
-          expect(plugins["foo"]["system"]).to be_false
+          expect(plugins["foo"]["system"]).to be_truthy
           expect(plugins).to have_key("bar")
-          expect(plugins["bar"]["system"]).to be_true
+          expect(plugins["bar"]["system"]).to be(true)
         end
       end
     end
