@@ -4,6 +4,6 @@ describe Vagrant::Plugin::V1::Communicator do
   let(:machine)  { Object.new }
 
   it "should not match by default" do
-    described_class.match?(machine).should_not be
+    expect(described_class.match?(machine)).not_to be
   end
 end
