@@ -59,31 +59,31 @@ describe Vagrant do
         name "i_am_installed"
       end
 
-      expect(described_class.has_plugin?("i_am_installed")).to be_true
+      expect(described_class.has_plugin?("i_am_installed")).to be(true)
     end
 
     it "should return false if the plugin is not installed" do
-      expect(described_class.has_plugin?("i_dont_exist")).to be_false
+      expect(described_class.has_plugin?("i_dont_exist")).to be(false)
     end
 
     it "finds plugins by gem name" do
       specs = [Gem::Specification.new]
       specs[0].name = "foo"
-      Vagrant::Plugin::Manager.instance.stub(installed_specs: specs)
+      allow(Vagrant::Plugin::Manager.instance).to receive(:installed_specs).and_return(specs)
 
-      expect(described_class.has_plugin?("foo")).to be_true
-      expect(described_class.has_plugin?("bar")).to be_false
+      expect(described_class.has_plugin?("foo")).to be(true)
+      expect(described_class.has_plugin?("bar")).to be(false)
     end
 
     it "finds plugins by gem name and version" do
       specs = [Gem::Specification.new]
       specs[0].name = "foo"
       specs[0].version = "1.2.3"
-      Vagrant::Plugin::Manager.instance.stub(installed_specs: specs)
+      allow(Vagrant::Plugin::Manager.instance).to receive(:installed_specs).and_return(specs)
 
-      expect(described_class.has_plugin?("foo", "~> 1.2.0")).to be_true
-      expect(described_class.has_plugin?("foo", "~> 1.0.0")).to be_false
-      expect(described_class.has_plugin?("bar", "~> 1.2.0")).to be_false
+      expect(described_class.has_plugin?("foo", "~> 1.2.0")).to be(true)
+      expect(described_class.has_plugin?("foo", "~> 1.0.0")).to be(false)
+      expect(described_class.has_plugin?("bar", "~> 1.2.0")).to be(false)
     end
   end
 
